/*
 * Copyright (c) 2011 Imre Fazekas.
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the Brillien nor the names of its
 * terms and concepts may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package com.vii.brillien.services;

import com.vii.brillien.core.management.BrillienServices;
import com.vii.brillien.ignition.BrillienContext;
import com.vii.brillien.kernel.BrillienException;
import com.vii.brillien.services.components.time.Timer;
import com.vii.brillien.services.components.util.MessageQueue;
import com.vii.brillien.services.web.BrillienDispatcherServlet;
import com.vii.streamline.webserver.WebServer;

import java.util.logging.Level;

/**
 * Loader class to publish presences defined in services modul of Brillien
 */
public class ServiceLoader {

    public static void main(String[] args) throws BrillienException {

        BrillienServices.liaison.registerPresence( Timer.class );
        BrillienServices.liaison.registerPresence( MessageQueue.class );

        if( BrillienContext.WEBSERVER_ON ){
            BrillienContext.systemLog( Level.CONFIG, "Adding "+ BrillienDispatcherServlet.class.getName() + " servlet to the Web server..." );

            WebServer.addBrillienService(
                BrillienDispatcherServlet.getServletInstance()
            );

            BrillienContext.systemLog( Level.CONFIG, BrillienDispatcherServlet.class.getName() + " servlet added to the Web server..." );
        }
    }

}
